pub struct LocalObjectStore { /* private fields */ }Expand description
Filesystem-backed content-addressed object store.
Implementations
Sourceimpl LocalObjectStore
impl LocalObjectStore
Sourcepub fn open(root: impl Into<PathBuf>) -> ImageResult<Self>
pub fn open(root: impl Into<PathBuf>) -> ImageResult<Self>
Open or create a local object store rooted at root.
Sourcepub fn put_bytes(&self, bytes: &[u8]) -> ImageResult<ObjectId>
pub fn put_bytes(&self, bytes: &[u8]) -> ImageResult<ObjectId>
Store exact bytes durably and return their immutable identity.
Sourcepub fn object_path(&self, id: &ObjectId) -> PathBuf
pub fn object_path(&self, id: &ObjectId) -> PathBuf
Return the confined path of a stored object.