pub enum Ext4Error {
Io(Error),
TooSmall,
Layout(String),
}Expand description
Errors that can occur during ext4 formatting.
Variants
Io(Error)
An I/O error occurred while writing the image.
TooSmall
The requested image size is too small to hold the minimum metadata and journal.
Layout(String)
The requested tree cannot be serialized by this minimal formatter.