pub async fn load_archive(
cache_dir: &Path,
input: &Path,
options: ImageLoadOptions,
) -> ImageResult<Vec<LoadedImage>>Expand description
Load a Docker image archive into the microsandbox image cache.
pub async fn load_archive(
cache_dir: &Path,
input: &Path,
options: ImageLoadOptions,
) -> ImageResult<Vec<LoadedImage>>Load a Docker image archive into the microsandbox image cache.