pub struct RegistryBuilder { /* private fields */ }Expand description
Builder for constructing a Registry client with optional auth and TLS settings.
Implementations
Sourceimpl RegistryBuilder
impl RegistryBuilder
Sourcepub fn auth(self, auth: RegistryAuth) -> Self
pub fn auth(self, auth: RegistryAuth) -> Self
Set authentication credentials for the registry.
Sourcepub fn add_insecure_registries(self, registries: Vec<String>) -> Self
pub fn add_insecure_registries(self, registries: Vec<String>) -> Self
Add registries that should be accessed over plain HTTP instead of HTTPS.
Sourcepub fn extra_ca_certs(self, certs: Vec<Vec<u8>>) -> Self
pub fn extra_ca_certs(self, certs: Vec<Vec<u8>>) -> Self
Add PEM-encoded CA root certificates to trust.
Sourcepub fn build(self) -> ImageResult<Registry>
pub fn build(self) -> ImageResult<Registry>
Build the registry client.
Returns ImageError::InvalidCertificate if any PEM data in
extra_ca_certs cannot be parsed as valid certificates.