pub struct IngestResult {
pub tree: FileTree,
pub uncompressed_digest: String,
}Expand description
Ingest a compressed tar stream, automatically decompressing based on the specified compression format. Result of tar ingestion including the decompressed content hash.
Fields
tree: FileTreeThe in-memory file tree built from the tar stream.
uncompressed_digest: StringSHA-256 hex digest of the decompressed tar stream (the OCI diff_id).