pub fn format_ext4(
path: &Path,
options: &Ext4FormatOptions,
) -> Result<(), Ext4Error>Expand description
Create and format a sparse ext4 filesystem image at path.
The image is suitable for use as an overlayfs upper layer. It is created as a sparse file so the initial on-disk footprint is minimal despite the large logical size.