GlobalCache

Struct GlobalCache 

pub struct GlobalCache { /* private fields */ }
On-disk global cache for OCI layers and EROFS images.

Layout:

~/.microsandbox/cache/manifests/<sha256-of-ref>.json       # manifest + config metadata
~/.microsandbox/cache/tmp/<blob>.part                      # partial downloads
~/.microsandbox/cache/tmp/<blob>.download.lock             # download flock files
~/.microsandbox/cache/tmp/<blob>.work/                     # materialization work dirs
~/.microsandbox/cache/layers/<diff_id_safe>.erofs          # per-layer EROFS
~/.microsandbox/cache/layers/<diff_id_safe>.erofs.lock     # materialization flock
~/.microsandbox/cache/fsmeta/<manifest_safe>.erofs         # fsmeta EROFS (fsmerge metadata)
~/.microsandbox/cache/fsmeta/<manifest_safe>.erofs.lock    # materialization flock
~/.microsandbox/cache/vmdk/<manifest_safe>.vmdk            # VMDK descriptor
~/.microsandbox/cache/vmdk/<manifest_safe>.vmdk.lock       # materialization flock

Implementations

Source

impl GlobalCache

pub fn new(cache_dir: &Path) -> ImageResult<Self>

Create a new GlobalCache using the provided cache directory.

Creates all subdirectories if they don’t exist.

pub async fn new_async(cache_dir: &Path) -> ImageResult<Self>

Create a new GlobalCache using async filesystem operations.

pub fn layers_dir(&self) -> &Path

Root layer EROFS cache directory.

pub fn layer_erofs_path(&self, diff_id: &Digest) -> PathBuf

Path to the per-layer EROFS image for a given diff_id.

pub fn layer_erofs_lock_path(&self, diff_id: &Digest) -> PathBuf

Path to the materialization lock for a layer EROFS image.

pub fn is_layer_materialized(&self, diff_id: &Digest) -> bool

Check if a layer EROFS image exists.

pub fn all_layers_materialized(&self, diff_ids: &[Digest]) -> bool

Check if all given layer diff_ids have materialized EROFS images.

pub fn fsmeta_dir(&self) -> &Path

Root fsmeta EROFS cache directory.

pub fn fsmeta_erofs_path(&self, manifest_digest: &Digest) -> PathBuf

Path to the fsmeta EROFS image for a given manifest digest.

pub fn fsmeta_erofs_lock_path(&self, manifest_digest: &Digest) -> PathBuf

Path to the materialization lock for a fsmeta EROFS image.

pub fn is_fsmeta_materialized(&self, manifest_digest: &Digest) -> bool

Check if a fsmeta EROFS image exists.

pub fn vmdk_dir(&self) -> &Path

Root VMDK cache directory.

pub fn vmdk_path(&self, manifest_digest: &Digest) -> PathBuf

Path to the VMDK descriptor for a given manifest digest.

pub fn vmdk_lock_path(&self, manifest_digest: &Digest) -> PathBuf

Path to the materialization lock for a VMDK descriptor.

pub fn is_vmdk_materialized(&self, manifest_digest: &Digest) -> bool

Check if a VMDK descriptor exists for a given manifest digest.

pub fn tmp_dir(&self) -> &Path

Root staging directory.

pub fn part_path(&self, blob_digest: &Digest) -> PathBuf

Path to the partial download file for a blob.

pub fn download_lock_path(&self, blob_digest: &Digest) -> PathBuf

Path to the download lock file for a blob.

pub fn work_dir(&self, key: &Digest) -> PathBuf

Path to the materialization work directory for an EROFS build.

pub fn manifests_dir(&self) -> &Path

Root manifest metadata directory.

pub fn image_lock_path(&self, reference: &Reference) -> PathBuf

Path to the pull lock file for an image reference.

pub fn read_image_metadata( &self, reference: &Reference, ) -> ImageResult<Option<CachedImageMetadata>>

Read cached metadata for an image reference.

pub async fn read_image_metadata_async( &self, reference: &Reference, ) -> ImageResult<Option<CachedImageMetadata>>

Read cached metadata for an image reference using async filesystem I/O.

pub fn delete_image_metadata(&self, reference: &Reference) -> ImageResult<()>

Delete cached metadata for an image reference.

pub async fn delete_image_metadata_async( &self, reference: &Reference, ) -> ImageResult<()>

Delete cached metadata for an image reference using async filesystem I/O.

pub fn tar_path(&self, digest: &Digest) -> PathBuf

Path to the cached compressed tarball for a layer blob.