Platform

Struct Platform 

pub struct Platform {
    pub os: String,
    pub arch: String,
    pub variant: Option<String>,
}
Target platform for OCI image resolution.

Used to select the correct manifest from a multi-platform OCI index.

Fields

os: String

Operating system (always linux for microsandbox).

arch: String

CPU architecture (e.g., amd64, arm64).

variant: Option<String>

Optional architecture variant (e.g., v7 for armv7).

Implementations

Source

impl Platform

pub fn new(os: impl Into<String>, arch: impl Into<String>) -> Self

Create a new platform.

pub fn with_variant( os: impl Into<String>, arch: impl Into<String>, variant: impl Into<String>, ) -> Self

Create a new platform with variant.

pub fn host_linux() -> Self

Returns the platform for the current host, with OS forced to linux.

Architecture detected via std::env::consts::ARCH: x86_64 -> amd64, aarch64 -> arm64.